LogEntry class

Constructors

LogEntry({required String id, required String message, required LogLevel level, required String timestamp, String? stackTrace})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
level LogLevel
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace String?
final
timestamp String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited