ApiClient class

Constructors

ApiClient({required AuthManager authManager, required String projectId})

Properties

authManager AuthManager
final
hashCode int
The hash code for this object.
no setterinherited
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverUrl String
final

Methods

claimNextJob(String? customPattern) Future<BuildJob?>
Claims the next queued build job for this platform.
completeJob(String id, String status) Future<void>
Completes a build job.
createRun(String buildJobId, String runId) Future<void>
Creates a build run record in Firestore.
getSecrets(String teamId) Future<List<Map<String, dynamic>>>
Retrieves secrets associated with the team.
getSecretValue(String teamId, String name) Future<String>
Fetches a Secret Value via Firebase Functions.
handleBuildJobStatusChange(BuildJob buildJob, String status) Future<void>
Handles Build Job status changes (notifications, etc).
isJobCancelled(String buildJobId) Future<bool>
Checks if a job has been cancelled in Firestore.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveInstallationToken(String buildJobId) Future<Map<String, dynamic>>
Resolves the Installation Access Token via Firebase Functions.
saveSecret({required String teamId, required String name, required String value}) Future<void>
Saves or updates a secret value associated with the team.
sendHeartbeat({required String workerId, required String version, required String status}) Future<void>
Sends the worker heartbeat status.
toString() String
A string representation of this object.
inherited
updateCheckRun(BuildJob buildJob, String runStatus, {String? conclusion}) Future<void>
Updates GitHub Check Run status.
updateRunStatus({required String buildJobId, required String runId, required String status, String? conclusion}) Future<void>
Updates a build run's status.

Operators

operator ==(Object other) bool
The equality operator.
inherited