AuthManager class

Constructors

AuthManager({required String apiKey, required String email, required String password})

Properties

apiKey String
final
email String
final
hashCode int
The hash code for this object.
no setterinherited
password String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getIdToken({bool forceRefresh = false}) Future<String>
Returns the current ID token, refreshing it if it's expired or close to expiry.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signIn() Future<void>
Signs in to Firebase Auth using Email & Password.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited